import zetane
import unittest
import mlflow
import pandas as pd
import numpy as np
import requests
import time

header = {"Authorization": 'Bearer eyJ1c2VyaWQiOiAiMiIsICJleHAiOiAiMDIvMDIvMjAyMywgMTg6NTI6MjUifQ==.3t82fdQBmKwBtkM3U71LWV7g0nAjRka2EHlpa0Ev0/JS1eAgbZ4tj0U9uGdP/m6Sv8o9/GwxMavXbWTa5Bc6Dg=='}
URL = 'http://localhost:8000/api/'

class API_Test(unittest.TestCase):



    def test_api(self):


        p = zetane.Protector(api_key=self.getAPIToken()['token'], org="roy@zetane.com", project="django proj")
        self.assertTrue(p.org == "roy@zetane.com")
        p.upload_model('test_data/jets_model_latest.zip')
        p.upload_dataset('test_data/jets_set.zip')
        p.report('../testActual.json', autoRun=True)



        s1,s2,s3 = self.reset(p.org, p.project, p)

        self.assertTrue(s1==s2)
        self.assertTrue(s2==s3)
        self.assertTrue(s1 == 200)
        self.assertTrue(s2 == 200)
        self.assertTrue(s3 == 200)
        self.assertTrue(s1 == s2 == s3 == 200, True)



    def reset(self, org, project, p):
        url = URL +  org + '/' + project

        models, datasets, run_names = self.getNames(p.org, p.project, p)
        print(models, datasets, run_names)
        req1 = requests.delete(url + '/datasets/delete/', headers=header, json={'ids': datasets})
        req2 = requests.delete(url + '/models/delete/', headers=header, json={'ids':models})
        req3 = requests.delete(url + '/runs/delete/', headers=header, json={'ids': run_names})
        print(req1.status_code, req2.status_code, req3.status_code)
        return req1.status_code, req2.status_code, req3.status_code

    def getNames(self, org, project, p):
        url = URL + org + '/' + project
        dataset_names = requests.get(url+'/datasets' , headers=header).json()
        model_names = requests.get(url+'/models' , headers=header).json()
        run_names = requests.get(url+'/runs' , headers=header).json()
        print(p.model)
        model_ids = [str(v['id']) for v in model_names]
        dataset_names = [str(v['id']) for v in dataset_names if v['name'] == p.dataset]
        run_names = [str(v['id']) for v in run_names]

        return model_ids, dataset_names, run_names

    def getAPIToken(self):
        token = requests.get(f'{URL}token', headers=header).json()
        return token

if __name__ == '__main__':
    unittest.main()






from setuptools import setup, find_packages

setup(
    name = "zetane",
    author="Zetane Systems",
    author_email="info@zetane.com",
    description = "Zetane Protector API",
    long_description="""Zetane Protector API is an automated platform for testing and improving the robustness of machine learning models and their data. It provides data scientists and operators with insights into proposed machine learning solutions and helps validate, understand, and analyze the operational boundaries of machine learning data and models prior to deployment.\n\nVisit our [docs](https://docs.zetane.com) for more details.""",
    long_description_content_type="text/markdown",
    version = "0.2.0",
    license="LICENSE.md",
    url="https://zetane.com",
    packages=find_packages(include=('protector.*','zetane')),
    entry_points = {
        'console_scripts': [
            'zetane = zetane.__main__:main'
        ]
    },
    python_requires='>=3.7',
    install_requires = ['python-dotenv', 'tqdm', 'requests', 'numpy'],
    include_package_data=True,
    package_data={'zetane': ['*.json']},)



from .protector import Protector
from dotenv import load_dotenv
import os

""" Settings """
api_key = None
default_client = None

load_dotenv()

if "API_KEY" in os.environ:
    api_key = os.getenv("API_KEY")

def auth_check(*args):
  print(*args)
  self = args[0]
  if not hasattr(self, 'api_key') or not self.api_key:
      raise TypeError('Failed to authenticate API key')
  print('DECORATOR SUCCESSFUL AUTH')


def config(*args, **kwargs):
  _proxy('config', *args, **kwargs)

def upload_dataset(*args, **kwargs):
  _proxy('upload_dataset', *args, **kwargs)

def upload_model(*args, **kwargs):
  _proxy('upload_model', *args, **kwargs)

def get_entries(*args, **kwargs):
  _proxy('get_entries', *args, **kwargs)

def get_orgs_and_projects(*args, **kwargs):
  _proxy('get_orgs_and_projects', *args, **kwargs)

def report(*args, **kwargs):
  _proxy('report', *args, **kwargs)

def get_report_status(*args, **kwargs):
  _proxy('get_report_status', *args, **kwargs)

def _proxy(method, *args, **kwargs):
    """Create an analytics client if one doesn't exist and send to it."""
    global default_client
    if not default_client:
      default_client = Protector(api_key)

    fn = getattr(default_client, method)
    fn(*args, **kwargs)
